pub struct HttpClients {
    pub html: Client,
    pub gql: Client,
    pub website_rss_url: String,
    pub github_rest_url: String,
    pub github_gql_url: String,
    pub repo_owner: String,
    pub repo_name: String,
    pub discussion_category: String,
    pub lookback_days: i64,
}
Monostruct containing the HTML and GraphQL clients used to create the discussion, along with the necessary URLs.

Fields

html: Client

HTML client for accessing the RSS feed, blog post, and GitHub REST API.

gql: Client

GraphQL client for accessing the GitHub GraphQL API. This client must be created with the following headers, using ClientBuilder::default_headers:

  • Accept: application/vnd.github+json
  • Authorization: <GitHub token>
  • User-Agent: <appropriate user agent name>
  • X-Github-Next-Global-ID: 1
website_rss_url: String

URL for the blog’s RSS feed.

github_rest_url: String

URL for GitHub REST API, typically https://api.github.com

github_gql_url: String

URL for GitHub GraphQL API, typically https://api.github.com/graphql

repo_owner: String

Owner of the repository hosting the comments.

repo_name: String

Name of the repository hosting the comments

discussion_category: String

Name of the discussion category that the comments should be posted under.

lookback_days: i64

The number of days to look back in history, to check if a previous discussion occurred. Limit is disabled if set to 0.

Implementations

source

impl HttpClients

source

pub fn init() -> Arc<Self>

Create the reqwest clients, and pull the other values from environment variables. These are assumed to be formatted like the default values available in GitHub Actions, except for DISCUSSION_CATEGORY and LOOKBACK_DAYS:

use std::env;
use rss_autogen_giscus::HttpClients;

env::set_var("WEBSITE_RSS_URL", "https://rss.cbc.ca/lineup/topstories.xml");
env::set_var("GITHUB_TOKEN", "secret_github_pat");
env::set_var("GITHUB_REPOSITORY_OWNER", "microsoft");
env::set_var("GITHUB_REPOSITORY", "microsoft/vscode");
env::set_var("DISCUSSION_CATEGORY", "CBC News");
env::set_var("LOOKBACK_DAYS", "0");

let clients = HttpClients::init();